google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.BaselineValueFormat View Source
Formatting options for baseline value.
Attributes
comparisonType(type:String.t, default:nil) - The comparison type of key value with baseline value.description(type:String.t, default:nil) - Description which is appended after the baseline value. This field is optional.negativeColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - Color to be used, in case baseline value represents a negative change for key value. This field is optional.position(type:GoogleApi.Sheets.V4.Model.TextPosition.t, default:nil) - Specifies the horizontal text positioning of baseline value. This field is optional. If not specified, default positioning is used.positiveColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - Color to be used, in case baseline value represents a positive change for key value. This field is optional.textFormat(type:GoogleApi.Sheets.V4.Model.TextFormat.t, default:nil) - Text formatting options for baseline value.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.BaselineValueFormat{
comparisonType: String.t(),
description: String.t(),
negativeColor: GoogleApi.Sheets.V4.Model.Color.t(),
position: GoogleApi.Sheets.V4.Model.TextPosition.t(),
positiveColor: GoogleApi.Sheets.V4.Model.Color.t(),
textFormat: GoogleApi.Sheets.V4.Model.TextFormat.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.