google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.BasicChartAxis View Source
An axis of the chart. A chart may not have more than one axis per axis position.
Attributes
format(type:GoogleApi.Sheets.V4.Model.TextFormat.t, default:nil) - The format of the title. Only valid if the axis is not associated with the domain.position(type:String.t, default:nil) - The position of this axis.title(type:String.t, default:nil) - The title of this axis. If set, this overrides any title inferred from headers of the data.titleTextPosition(type:GoogleApi.Sheets.V4.Model.TextPosition.t, default:nil) - The axis title text position.viewWindowOptions(type:GoogleApi.Sheets.V4.Model.ChartAxisViewWindowOptions.t, default:nil) - The view window options for this axis.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.BasicChartAxis{
format: GoogleApi.Sheets.V4.Model.TextFormat.t(),
position: String.t(),
title: String.t(),
titleTextPosition: GoogleApi.Sheets.V4.Model.TextPosition.t(),
viewWindowOptions: GoogleApi.Sheets.V4.Model.ChartAxisViewWindowOptions.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.