google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.BatchUpdateValuesResponse View Source
The response when updating a range of values in a spreadsheet.
Attributes
responses(type:list(GoogleApi.Sheets.V4.Model.UpdateValuesResponse.t), default:nil) - One UpdateValuesResponse per requested range, in the same order as the requests appeared.spreadsheetId(type:String.t, default:nil) - The spreadsheet the updates were applied to.totalUpdatedCells(type:integer(), default:nil) - The total number of cells updated.totalUpdatedColumns(type:integer(), default:nil) - The total number of columns where at least one cell in the column was updated.totalUpdatedRows(type:integer(), default:nil) - The total number of rows where at least one cell in the row was updated.totalUpdatedSheets(type:integer(), default:nil) - The total number of sheets where at least one cell in the sheet was updated.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.