google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.BooleanRule View Source
A rule that may or may not match, depending on the condition.
Attributes
condition(type:GoogleApi.Sheets.V4.Model.BooleanCondition.t, default:nil) - The condition of the rule. If the condition evaluates to true, the format is applied.format(type:GoogleApi.Sheets.V4.Model.CellFormat.t, default:nil) - The format to apply. Conditional formatting can only apply a subset of formatting: bold, italic, strikethrough, foreground color & background color.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.BooleanRule{
condition: GoogleApi.Sheets.V4.Model.BooleanCondition.t(),
format: GoogleApi.Sheets.V4.Model.CellFormat.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.