google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.CellFormat View Source
The format of a cell.
Attributes
backgroundColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The background color of the cell.borders(type:GoogleApi.Sheets.V4.Model.Borders.t, default:nil) - The borders of the cell.horizontalAlignment(type:String.t, default:nil) - The horizontal alignment of the value in the cell.hyperlinkDisplayType(type:String.t, default:nil) - How a hyperlink, if it exists, should be displayed in the cell.numberFormat(type:GoogleApi.Sheets.V4.Model.NumberFormat.t, default:nil) - A format describing how number values should be represented to the user.padding(type:GoogleApi.Sheets.V4.Model.Padding.t, default:nil) - The padding of the cell.textDirection(type:String.t, default:nil) - The direction of the text in the cell.textFormat(type:GoogleApi.Sheets.V4.Model.TextFormat.t, default:nil) - The format of the text in the cell (unless overridden by a format run).textRotation(type:GoogleApi.Sheets.V4.Model.TextRotation.t, default:nil) - The rotation applied to text in a cellverticalAlignment(type:String.t, default:nil) - The vertical alignment of the value in the cell.wrapStrategy(type:String.t, default:nil) - The wrap strategy for the value in the cell.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.CellFormat{
backgroundColor: GoogleApi.Sheets.V4.Model.Color.t(),
borders: GoogleApi.Sheets.V4.Model.Borders.t(),
horizontalAlignment: String.t(),
hyperlinkDisplayType: String.t(),
numberFormat: GoogleApi.Sheets.V4.Model.NumberFormat.t(),
padding: GoogleApi.Sheets.V4.Model.Padding.t(),
textDirection: String.t(),
textFormat: GoogleApi.Sheets.V4.Model.TextFormat.t(),
textRotation: GoogleApi.Sheets.V4.Model.TextRotation.t(),
verticalAlignment: String.t(),
wrapStrategy: String.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.