google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.ChartAxisViewWindowOptions View Source
The options that define a "view window" for a chart (such as the visible values in an axis).
Attributes
viewWindowMax(type:float(), default:nil) - The maximum numeric value to be shown in this view window. If unset, will automatically determine a maximum value that looks good for the data.viewWindowMin(type:float(), default:nil) - The minimum numeric value to be shown in this view window. If unset, will automatically determine a minimum value that looks good for the data.viewWindowMode(type:String.t, default:nil) - The view window's mode.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.