google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.ChartCustomNumberFormatOptions View Source
Custom number formatting options for chart attributes.
Attributes
prefix(type:String.t, default:nil) - Custom prefix to be prepended to the chart attribute. This field is optional.suffix(type:String.t, default:nil) - Custom suffix to be appended to the chart attribute. This field is optional.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.