google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.ChartSpec View Source
The specifications of a chart.
Attributes
altText(type:String.t, default:nil) - The alternative text that describes the chart. This is often used for accessibility.backgroundColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The background color of the entire chart. Not applicable to Org charts.basicChart(type:GoogleApi.Sheets.V4.Model.BasicChartSpec.t, default:nil) - A basic chart specification, can be one of many kinds of charts. See BasicChartType for the list of all charts this supports.bubbleChart(type:GoogleApi.Sheets.V4.Model.BubbleChartSpec.t, default:nil) - A bubble chart specification.candlestickChart(type:GoogleApi.Sheets.V4.Model.CandlestickChartSpec.t, default:nil) - A candlestick chart specification.fontName(type:String.t, default:nil) - The name of the font to use by default for all chart text (e.g. title, axis labels, legend). If a font is specified for a specific part of the chart it will override this font name.hiddenDimensionStrategy(type:String.t, default:nil) - Determines how the charts will use hidden rows or columns.histogramChart(type:GoogleApi.Sheets.V4.Model.HistogramChartSpec.t, default:nil) - A histogram chart specification.maximized(type:boolean(), default:nil) - True to make a chart fill the entire space in which it's rendered with minimum padding. False to use the default padding. (Not applicable to Geo and Org charts.)orgChart(type:GoogleApi.Sheets.V4.Model.OrgChartSpec.t, default:nil) - An org chart specification.pieChart(type:GoogleApi.Sheets.V4.Model.PieChartSpec.t, default:nil) - A pie chart specification.scorecardChart(type:GoogleApi.Sheets.V4.Model.ScorecardChartSpec.t, default:nil) - A scorecard chart specification.subtitle(type:String.t, default:nil) - The subtitle of the chart.subtitleTextFormat(type:GoogleApi.Sheets.V4.Model.TextFormat.t, default:nil) - The subtitle text format. Strikethrough and underline are not supported.subtitleTextPosition(type:GoogleApi.Sheets.V4.Model.TextPosition.t, default:nil) - The subtitle text position. This field is optional.title(type:String.t, default:nil) - The title of the chart.titleTextFormat(type:GoogleApi.Sheets.V4.Model.TextFormat.t, default:nil) - The title text format. Strikethrough and underline are not supported.titleTextPosition(type:GoogleApi.Sheets.V4.Model.TextPosition.t, default:nil) - The title text position. This field is optional.treemapChart(type:GoogleApi.Sheets.V4.Model.TreemapChartSpec.t, default:nil) - A treemap chart specification.waterfallChart(type:GoogleApi.Sheets.V4.Model.WaterfallChartSpec.t, default:nil) - A waterfall chart specification.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.ChartSpec{
altText: String.t(),
backgroundColor: GoogleApi.Sheets.V4.Model.Color.t(),
basicChart: GoogleApi.Sheets.V4.Model.BasicChartSpec.t(),
bubbleChart: GoogleApi.Sheets.V4.Model.BubbleChartSpec.t(),
candlestickChart: GoogleApi.Sheets.V4.Model.CandlestickChartSpec.t(),
fontName: String.t(),
hiddenDimensionStrategy: String.t(),
histogramChart: GoogleApi.Sheets.V4.Model.HistogramChartSpec.t(),
maximized: boolean(),
orgChart: GoogleApi.Sheets.V4.Model.OrgChartSpec.t(),
pieChart: GoogleApi.Sheets.V4.Model.PieChartSpec.t(),
scorecardChart: GoogleApi.Sheets.V4.Model.ScorecardChartSpec.t(),
subtitle: String.t(),
subtitleTextFormat: GoogleApi.Sheets.V4.Model.TextFormat.t(),
subtitleTextPosition: GoogleApi.Sheets.V4.Model.TextPosition.t(),
title: String.t(),
titleTextFormat: GoogleApi.Sheets.V4.Model.TextFormat.t(),
titleTextPosition: GoogleApi.Sheets.V4.Model.TextPosition.t(),
treemapChart: GoogleApi.Sheets.V4.Model.TreemapChartSpec.t(),
waterfallChart: GoogleApi.Sheets.V4.Model.WaterfallChartSpec.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.