google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.ConditionalFormatRule View Source
A rule describing a conditional format.
Attributes
booleanRule(type:GoogleApi.Sheets.V4.Model.BooleanRule.t, default:nil) - The formatting is either "on" or "off" according to the rule.gradientRule(type:GoogleApi.Sheets.V4.Model.GradientRule.t, default:nil) - The formatting will vary based on the gradients in the rule.ranges(type:list(GoogleApi.Sheets.V4.Model.GridRange.t), default:nil) - The ranges that are formatted if the condition is true. All the ranges must be on the same grid.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.ConditionalFormatRule{
booleanRule: GoogleApi.Sheets.V4.Model.BooleanRule.t(),
gradientRule: GoogleApi.Sheets.V4.Model.GradientRule.t(),
ranges: [GoogleApi.Sheets.V4.Model.GridRange.t()]
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.