google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.Editors View Source
The editors of a protected range.
Attributes
domainUsersCanEdit(type:boolean(), default:nil) - True if anyone in the document's domain has edit access to the protected range. Domain protection is only supported on documents within a domain.groups(type:list(String.t), default:nil) - The email addresses of groups with edit access to the protected range.users(type:list(String.t), default:nil) - The email addresses of users with edit access to the protected range.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.