google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.FilterCriteria View Source
Criteria for showing/hiding rows in a filter or filter view.
Attributes
condition(type:GoogleApi.Sheets.V4.Model.BooleanCondition.t, default:nil) - A condition that must be true for values to be shown. (This does not override hidden_values -- if a value is listed there, it will still be hidden.)hiddenValues(type:list(String.t), default:nil) - Values that should be hidden.visibleBackgroundColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The background fill color to filter by; only cells with this fill color are shown. Mutually exclusive with all other filter criteria. Requests to set this field will fail with a 400 error if any other filter criteria field is set.visibleForegroundColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The text color to filter by; only cells with this text color are shown. Mutually exclusive with all other filter criteria. Requests to set this field will fail with a 400 error if any other filter criteria field is set.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.FilterCriteria{
condition: GoogleApi.Sheets.V4.Model.BooleanCondition.t(),
hiddenValues: [String.t()],
visibleBackgroundColor: GoogleApi.Sheets.V4.Model.Color.t(),
visibleForegroundColor: GoogleApi.Sheets.V4.Model.Color.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.