google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.GridData View Source
Data in the grid, as well as metadata about the dimensions.
Attributes
columnMetadata(type:list(GoogleApi.Sheets.V4.Model.DimensionProperties.t), default:nil) - Metadata about the requested columns in the grid, starting with the column in start_column.rowData(type:list(GoogleApi.Sheets.V4.Model.RowData.t), default:nil) - The data in the grid, one entry per row, starting with the row in startRow. The values in RowData will correspond to columns starting at start_column.rowMetadata(type:list(GoogleApi.Sheets.V4.Model.DimensionProperties.t), default:nil) - Metadata about the requested rows in the grid, starting with the row in start_row.startColumn(type:integer(), default:nil) - The first column this GridData refers to, zero-based.startRow(type:integer(), default:nil) - The first row this GridData refers to, zero-based.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.GridData{
columnMetadata: [GoogleApi.Sheets.V4.Model.DimensionProperties.t()],
rowData: [GoogleApi.Sheets.V4.Model.RowData.t()],
rowMetadata: [GoogleApi.Sheets.V4.Model.DimensionProperties.t()],
startColumn: integer(),
startRow: integer()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.