google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.HistogramSeries View Source
A histogram series containing the series color and data.
Attributes
barColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The color of the column representing this series in each bucket. This field is optional.data(type:GoogleApi.Sheets.V4.Model.ChartData.t, default:nil) - The data for this histogram series.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.HistogramSeries{
barColor: GoogleApi.Sheets.V4.Model.Color.t(),
data: GoogleApi.Sheets.V4.Model.ChartData.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.