google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.InterpolationPoint View Source
A single interpolation point on a gradient conditional format. These pin the gradient color scale according to the color, type and value chosen.
Attributes
color(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The color this interpolation point should use.type(type:String.t, default:nil) - How the value should be interpreted.value(type:String.t, default:nil) - The value this interpolation point uses. May be a formula. Unused if type is MIN or MAX.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.InterpolationPoint{
color: GoogleApi.Sheets.V4.Model.Color.t(),
type: String.t(),
value: String.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.