google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.OverlayPosition View Source
The location an object is overlaid on top of a grid.
Attributes
anchorCell(type:GoogleApi.Sheets.V4.Model.GridCoordinate.t, default:nil) - The cell the object is anchored to.heightPixels(type:integer(), default:nil) - The height of the object, in pixels. Defaults to 371.offsetXPixels(type:integer(), default:nil) - The horizontal offset, in pixels, that the object is offset from the anchor cell.offsetYPixels(type:integer(), default:nil) - The vertical offset, in pixels, that the object is offset from the anchor cell.widthPixels(type:integer(), default:nil) - The width of the object, in pixels. Defaults to 600.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.OverlayPosition{
anchorCell: GoogleApi.Sheets.V4.Model.GridCoordinate.t(),
heightPixels: integer(),
offsetXPixels: integer(),
offsetYPixels: integer(),
widthPixels: integer()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.