google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.PieChartSpec View Source
A pie chart.
Attributes
domain(type:GoogleApi.Sheets.V4.Model.ChartData.t, default:nil) - The data that covers the domain of the pie chart.legendPosition(type:String.t, default:nil) - Where the legend of the pie chart should be drawn.pieHole(type:float(), default:nil) - The size of the hole in the pie chart.series(type:GoogleApi.Sheets.V4.Model.ChartData.t, default:nil) - The data that covers the one and only series of the pie chart.threeDimensional(type:boolean(), default:nil) - True if the pie is three dimensional.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.PieChartSpec{
domain: GoogleApi.Sheets.V4.Model.ChartData.t(),
legendPosition: String.t(),
pieHole: float(),
series: GoogleApi.Sheets.V4.Model.ChartData.t(),
threeDimensional: boolean()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.