google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.PivotGroupRule View Source
An optional setting on a PivotGroup that defines buckets for the values in the source data column rather than breaking out each individual value. Only one PivotGroup with a group rule may be added for each column in the source data, though on any given column you may add both a PivotGroup that has a rule and a PivotGroup that does not.
Attributes
dateTimeRule(type:GoogleApi.Sheets.V4.Model.DateTimeRule.t, default:nil) - A DateTimeRule.histogramRule(type:GoogleApi.Sheets.V4.Model.HistogramRule.t, default:nil) - A HistogramRule.manualRule(type:GoogleApi.Sheets.V4.Model.ManualRule.t, default:nil) - A ManualRule.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.PivotGroupRule{
dateTimeRule: GoogleApi.Sheets.V4.Model.DateTimeRule.t(),
histogramRule: GoogleApi.Sheets.V4.Model.HistogramRule.t(),
manualRule: GoogleApi.Sheets.V4.Model.ManualRule.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.