google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.SlicerSpec View Source
The specifications of a slicer.
Attributes
applyToPivotTables(type:boolean(), default:nil) - True if the filter should apply to pivot tables. If not set, default toTrue.backgroundColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The background color of the slicer.columnIndex(type:integer(), default:nil) - The column index in the data table on which the filter is applied to.dataRange(type:GoogleApi.Sheets.V4.Model.GridRange.t, default:nil) - The data range of the slicer.filterCriteria(type:GoogleApi.Sheets.V4.Model.FilterCriteria.t, default:nil) - The filtering criteria of the slicer.horizontalAlignment(type:String.t, default:nil) - The horizontal alignment of title in the slicer. If unspecified, defaults toLEFTtextFormat(type:GoogleApi.Sheets.V4.Model.TextFormat.t, default:nil) - The text format of title in the slicer.title(type:String.t, default:nil) - The title of the slicer.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.SlicerSpec{
applyToPivotTables: boolean(),
backgroundColor: GoogleApi.Sheets.V4.Model.Color.t(),
columnIndex: integer(),
dataRange: GoogleApi.Sheets.V4.Model.GridRange.t(),
filterCriteria: GoogleApi.Sheets.V4.Model.FilterCriteria.t(),
horizontalAlignment: String.t(),
textFormat: GoogleApi.Sheets.V4.Model.TextFormat.t(),
title: String.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.