google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.SortSpec View Source
A sort order associated with a specific column or row.
Attributes
backgroundColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The background fill color to sort by. Mutually exclusive with sorting by text color. Requests to set this field will fail with a 400 error if foreground color is also set.dimensionIndex(type:integer(), default:nil) - The dimension the sort should be applied to.foregroundColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The text color to sort by. Mutually exclusive with sorting by background fill color. Requests to set this field will fail with a 400 error if background color is also set.sortOrder(type:String.t, default:nil) - The order data should be sorted.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.SortSpec{
backgroundColor: GoogleApi.Sheets.V4.Model.Color.t(),
dimensionIndex: integer(),
foregroundColor: GoogleApi.Sheets.V4.Model.Color.t(),
sortOrder: String.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.