google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.SpreadsheetProperties View Source
Properties of a spreadsheet.
Attributes
autoRecalc(type:String.t, default:nil) - The amount of time to wait before volatile functions are recalculated.defaultFormat(type:GoogleApi.Sheets.V4.Model.CellFormat.t, default:nil) - The default format of all cells in the spreadsheet. CellData.effectiveFormat will not be set if the cell's format is equal to this default format. This field is read-only.iterativeCalculationSettings(type:GoogleApi.Sheets.V4.Model.IterativeCalculationSettings.t, default:nil) - Determines whether and how circular references are resolved with iterative calculation. Absence of this field means that circular references will result in calculation errors.locale(type:String.t, default:nil) - The locale of the spreadsheet in one of the following formats:an ISO 639-1 language code such as
enan ISO 639-2 language code such as
fil, if no 639-1 code existsa combination of the ISO language code and country code, such as
en_US
Note: when updating this field, not all locales/languages are supported.
timeZone(type:String.t, default:nil) - The time zone of the spreadsheet, in CLDR format such asAmerica/New_York. If the time zone isn't recognized, this may be a custom time zone such asGMT-07:00.title(type:String.t, default:nil) - The title of the spreadsheet.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.SpreadsheetProperties{
autoRecalc: String.t(),
defaultFormat: GoogleApi.Sheets.V4.Model.CellFormat.t(),
iterativeCalculationSettings:
GoogleApi.Sheets.V4.Model.IterativeCalculationSettings.t(),
locale: String.t(),
timeZone: String.t(),
title: String.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.