google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.TreemapChartColorScale View Source
A color scale for a treemap chart.
Attributes
maxValueColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The background color for cells with a color value greater than or equal to maxValue. Defaults to #109618 if not specified.midValueColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The background color for cells with a color value at the midpoint between minValue and maxValue. Defaults to #efe6dc if not specified.minValueColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The background color for cells with a color value less than or equal to minValue. Defaults to #dc3912 if not specified.noDataColor(type:GoogleApi.Sheets.V4.Model.Color.t, default:nil) - The background color for cells that have no color data associated with them. Defaults to #000000 if not specified.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.TreemapChartColorScale{
maxValueColor: GoogleApi.Sheets.V4.Model.Color.t(),
midValueColor: GoogleApi.Sheets.V4.Model.Color.t(),
minValueColor: GoogleApi.Sheets.V4.Model.Color.t(),
noDataColor: GoogleApi.Sheets.V4.Model.Color.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.