google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.UpdateBordersRequest View Source
Updates the borders of a range. If a field is not set in the request, that means the border remains as-is. For example, with two subsequent UpdateBordersRequest:
- range: A1:A5
{ top: RED, bottom: WHITE } - range: A1:A5
{ left: BLUE }
That would result in A1:A5 having a borders of
{ top: RED, bottom: WHITE, left: BLUE }.
If you want to clear a border, explicitly set the style to
NONE.
Attributes
bottom(type:GoogleApi.Sheets.V4.Model.Border.t, default:nil) - The border to put at the bottom of the range.innerHorizontal(type:GoogleApi.Sheets.V4.Model.Border.t, default:nil) - The horizontal border to put within the range.innerVertical(type:GoogleApi.Sheets.V4.Model.Border.t, default:nil) - The vertical border to put within the range.left(type:GoogleApi.Sheets.V4.Model.Border.t, default:nil) - The border to put at the left of the range.range(type:GoogleApi.Sheets.V4.Model.GridRange.t, default:nil) - The range whose borders should be updated.right(type:GoogleApi.Sheets.V4.Model.Border.t, default:nil) - The border to put at the right of the range.top(type:GoogleApi.Sheets.V4.Model.Border.t, default:nil) - The border to put at the top of the range.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.UpdateBordersRequest{
bottom: GoogleApi.Sheets.V4.Model.Border.t(),
innerHorizontal: GoogleApi.Sheets.V4.Model.Border.t(),
innerVertical: GoogleApi.Sheets.V4.Model.Border.t(),
left: GoogleApi.Sheets.V4.Model.Border.t(),
range: GoogleApi.Sheets.V4.Model.GridRange.t(),
right: GoogleApi.Sheets.V4.Model.Border.t(),
top: GoogleApi.Sheets.V4.Model.Border.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.