google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.UpdateNamedRangeRequest View Source
Updates properties of the named range with the specified namedRangeId.
Attributes
fields(type:String.t, default:nil) - The fields that should be updated. At least one field must be specified. The rootnamedRangeis implied and should not be specified. A single"*"can be used as short-hand for listing every field.namedRange(type:GoogleApi.Sheets.V4.Model.NamedRange.t, default:nil) - The named range to update with the new properties.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.UpdateNamedRangeRequest{
fields: String.t(),
namedRange: GoogleApi.Sheets.V4.Model.NamedRange.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.