google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.UpdateProtectedRangeRequest View Source
Updates an existing protected range with the specified protectedRangeId.
Attributes
fields(type:String.t, default:nil) - The fields that should be updated. At least one field must be specified. The rootprotectedRangeis implied and should not be specified. A single"*"can be used as short-hand for listing every field.protectedRange(type:GoogleApi.Sheets.V4.Model.ProtectedRange.t, default:nil) - The protected range to update with the new properties.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this type
t()
View Sourcet() :: %GoogleApi.Sheets.V4.Model.UpdateProtectedRangeRequest{
fields: String.t(),
protectedRange: GoogleApi.Sheets.V4.Model.ProtectedRange.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.