google_api_sheets v0.15.0 GoogleApi.Sheets.V4.Model.UpdateValuesResponse View Source
The response when updating a range of values in a spreadsheet.
Attributes
spreadsheetId(type:String.t, default:nil) - The spreadsheet the updates were applied to.updatedCells(type:integer(), default:nil) - The number of cells updated.updatedColumns(type:integer(), default:nil) - The number of columns where at least one cell in the column was updated.updatedData(type:GoogleApi.Sheets.V4.Model.ValueRange.t, default:nil) - The values of the cells after updates were applied. This is only included if the request'sincludeValuesInResponsefield wastrue.updatedRange(type:String.t, default:nil) - The range (in A1 notation) that updates were applied to.updatedRows(type:integer(), default:nil) - The number of rows where at least one cell in the row was updated.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.